Welcome to BiAPoL utilities's documentation!
============================================

On this page, we provide documentation pages for our API and provide
comprehensive examples on how to use the functions in our library.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   _include/Examples
   _include/API_reference
   _include/Contribute


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Ressources
==================

   * BiAPoL group blog: `<https://biapol.github.io/blog/>`_.
   * Source code: `<https://github.com/BiAPoL/biapol-utilities>`_.